@@ -208,20 +208,50 @@ class FederatedPipelineBase(AMLPipelineHelper):
                 dict1[k] = v
         return dict1
 
+    def _get_user_defined_output_configs(self, component_instance):
+        output_configs = {}
+        for output_key in component_instance.outputs:
+            output_instance = getattr(component_instance.outputs, output_key)
+            config = {
+                "datastore": output_instance._datastore,
+                "mode": output_instance._mode,
+                "path_on_compute": output_instance._path_on_compute,
+                "path_on_datastore": output_instance._dataset_output_options.path_on_datastore
+                if output_instance._dataset_output_options
+                else None,
+            }
+            for k, v in dict(config).items():
+                if not v:
+                    del config[k]
+            if config:
+                output_configs[output_instance._name] = config
+        return output_configs
+
+    def _apply_user_defined_output_configs(self, outputs, output_configs):
+        for output_key in outputs:
+            if output_key in output_configs:
+                outputs[output_key].configure(**output_configs[output_key])
+        return outputs
+
     def _process_at_orchestrator(self, prev: StepOutput) -> dict:
         """Processes outputs at the orchestrator."""
         step = prev.step
         if isinstance(step, Pipeline):
             prev_output = step.outputs
         elif isinstance(step, Component):
+            prev_output = dataset_name_to_reference(step, prev.outputs)
+            log.info(f"Checking user override runsettings for {step.name}...")
+            output_configs = self._get_user_defined_output_configs(step)
+
             runsettings = step.runsettings._get_values()
             self.apply_smart_runsettings(step)
-            log.info(f"Checking user override runsettings for {step.name}...")
             merged_runsettings = self._update_nested_dict_with_non_none_values(
                 step.runsettings._get_values(), runsettings
             )
             step.runsettings._set_section_by_dict(merged_runsettings)
-            prev_output = dataset_name_to_reference(step, prev.outputs)
+            prev_output = self._apply_user_defined_output_configs(
+                prev_output, output_configs
+            )
         else:
             raise Exception(
                 f"The output of preprocess/midprocess/postprocess step must be a Pipeline object or a Component object. You are using {type(prev.step)}."
@@ -288,6 +318,12 @@ class FederatedPipelineBase(AMLPipelineHelper):
             for node in step._expand_pipeline_nodes():
                 node._node_name = self.create_silo_specific_name(silo_name)
         elif isinstance(step, Component):
+            train_output = dataset_name_to_reference(step, train_step.outputs)
+            log.info(
+                f"Checking user override runsettings for {silo_name} / {step.name}..."
+            )
+            output_configs = self._get_user_defined_output_configs(step)
+
             runsettings = step.runsettings._get_values()
             self.apply_smart_runsettings(
                 step,
@@ -298,7 +334,10 @@ class FederatedPipelineBase(AMLPipelineHelper):
                 step.runsettings._get_values(), runsettings
             )
             step.runsettings._set_section_by_dict(merged_runsettings)
-            train_output = dataset_name_to_reference(step, train_step.outputs)
+            train_output = self._apply_user_defined_output_configs(
+                train_output, output_configs
+            )
+
             step._node_name = self.create_silo_specific_name(silo_name)
 
         else:
